{% load wagtailcore_tags %}

<div {% if self.settings.custom_id %}id="{{self.settings.custom_id}}"{% endif %}
     class="col{% if self.settings.column_breakpoint %}-{{ self.settings.column_breakpoint }}{% endif %}{% if self.column_size %}-{{ self.column_size }}{% endif %} {{self.settings.custom_css_class}}">
      {% for block in self.content %}
      {% include_block block %}
      {% endfor %}
</div>