{% load friendly_loader wagtailcore_tags wagtailsettings_tags cjkcms_tags %}
{% friendly_load webpack_loader %}
    {% if settings.cjkcms.LayoutSettings.frontend_theme == 'python-webpack' %} {# use python-webpack from Michael Yin #}
        {% if_has_tag stylesheet_pack %}
            {% stylesheet_pack 'app' %}
        {% endif_has_tag %}
    {% elif settings.cjkcms.LayoutSettings.frontend_theme == 'mdb.light' %}
        <link href="https://cdnjs.cloudflare.com/ajax/libs/mdb-ui-kit/3.11.0/mdb.min.css"
              rel="stylesheet"
              crossorigin="anonymous">
    {% elif settings.cjkcms.LayoutSettings.frontend_theme == 'mdb.dark' %}
        <link href="https://cdnjs.cloudflare.com/ajax/libs/mdb-ui-kit/3.11.0/mdb.dark.min.css"
              rel="stylesheet"
              crossorigin="anonymous">
    {% else %}
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css"
              rel="stylesheet"
              crossorigin="anonymous"
              integrity="sha384-1BmE4kWBq78iYhFldvKuhfTAU6auU8tT94WrHftjDbrCEXSU1oBoqyl2QvZ6jIW3">
    {% endif %}
    {% if settings.cjkcms.LayoutSettings.awesome_cdn %}
        <!-- Font Awesome -->
        <link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.11.2/css/all.css" />
    {% endif %}
