.cjkcms-collapsible {
    padding: 0;
    margin-top: -40px;
}

.cjkcms-collapsible .cjkcms-collapsible-target {
    padding: 10px 0 0;
}

.cjkcms-collapsible>button {
    max-width: 140px;
}

.cjkcms-checkbox-group {
    margin-bottom: 1em;
}

.cjkcms-checkbox-group ul {
    margin-top: 0.5em;
}

.cjkcms-checkbox-group label {
    padding-bottom: 0.25em;
}

.cjkcms-checkbox-group label input {
    margin-right: 0.25em;
}

.cjkcms-callout {
    background-color: #f0f1f2;
    border-radius: 6px;
    display: inline-block;
    padding: 2em 3em;
    text-align: center;
}

.cjkcms-callout .codered-big-icon {
    font-size: 10rem;
    color: rgba(0, 0, 0, 0.1);
}

.cjkcms-callout h3 {
    font-size: 1.2rem;
    font-weight: 600;
}

.cjkcms-callout p {
    font-size: 1rem;
}

.Draftail-block--LEFT-ALIGN .public-DraftStyleDefault-ltr {
    text-align: start;
}

.Draftail-block--CENTRE-ALIGN .public-DraftStyleDefault-ltr {
    text-align: center;
}

.Draftail-block--RIGHT-ALIGN .public-DraftStyleDefault-ltr {
    text-align: end;
}